/* 
This program (formats_for_nrbs2013_weighted.sas) creates the formats
catalog for nrbs2013_weighted.sas7bdat.

Instructions for Windows users:

1. Create a folder for your files, e.g. c:\sasfiles
2. Place nrbs2013_weighted.sas7bdat and formats_for_nrbs2013_weighted.sas
   in the folder
3. Edit the libname statement in formats_for_nrbs2013_weighted.sas so that
   it refers to the folder, e.g.: libname library 'c:\sasfiles'
4. Open and run formats_for_nrbs2013_weighted.sas.  This will create
   the formats catalog, "formats.sas7bcat" in that folder.
5. You may now use nrbs2013_weighted.sas7bdat any way you
   like, for example the following program will create a frequency listing:

   libname library 'c:\sasfiles';
   proc freq data=library.nrbs2013_weighted; 
      tables _all_;
   run;

   Note that by using the name "library" for your libname when inputting the 
   data, SAS will automatically look in that same location for the formats
   catalog.  Otherwise, you would need to use a "fmtsearch" option to tell
   SAS where to look for the formats catalog.
*/

libname library '';

proc format library=library;

   value V00001F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00002F 
      1 = "01-YES - TRANSFERRING"
      2 = "02-UNAVAILABLE"
      99 = "99-REFUSAL"
   ;
   value V00003F 
      1 = "1-ANYBOAT"
   ;
   value V00004F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DK"
      99 = "99-REFUSED"
   ;
   value V00005F 
      1 = "01-YES"
      2 = "02-NO"
      3 = "03-NOT A SAFE TIME"
      97 = "97-DON'T KNOW/NOT SURE"
      99 = "99-REFUSED"
   ;
   value V00006F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW/NOT SURE"
      99 = "99-REFUSED"
   ;
   value V00007F 
      1 = "01-ALWAYS,"
      2 = "02-MOST OF THE TIME,"
      3 = "03-SOMETIMES,"
      4 = "04-RARELY, OR"
      5 = "05-NEVER?"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00008F 
      2 = "02-02"
      3 = "03-03"
      4 = "04-04"
      5 = "05-05"
      6 = "06-06"
      7 = "07-07"
      8 = "08-08"
      9 = "09-09"
      10 = "10-10"
   ;
   value V00009F 
      1 = "01-CONTINUE"
   ;
   value V00010F 
      1 = "1-\:WKIDS:"
      2 = "2-|KIDTOT|"
   ;
   value V00017F 
      1 = "01-AM"
      2 = "02-PM"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00019F 
      1 = "01-ALL/MOST ALL CALLS RECEIVED ON CELL PHONES"
      2 = "02-SOME ON CELL/SOME ON REGULAR PHONES"
      3 = "03-VERY FEW OR NONE ON CELL PHONES"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00021F 
      1 = "01-YES"
      2 = "02-NO"
   ;
   value V00022F 
      1 = "01-YES - CONTINUE"
      2 = "02-NO"
      3 = "03-ANSWERING MACHINE"
   ;
   value V00024F 
      1 = "01-LAUNCH RUN BY STATE BOATING FISHING AGENCY"
      2 = "02-LAUNCH RUN BY COUNTY OR LOCAL GOVERNMENT"
      3 = "03-LAUNCH RUN BY FEDERAL AGENCY"
      4 = "04-LAUNCH AT A MARINA OR DRY STACK"
      5 = "05-PRIVATELY OWNED/OPERATED LAUNCH SITE"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00025F 
      1 = "01-RECORD RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00028F 
      1 = "01-SUCCESSFUL TRANSFER"
      2 = "02-REFUSE TO TRANSFER"
      3 = "03-CALLBACK TO COMPLETE"
   ;
   value V00029F 
      1 = "01-5 OR YOUNGER,"
      2 = "02-6 TO 10,"
      3 = "03-11 TO 15,"
      4 = "04-16 TO 17,"
      5 = "05-18 TO 24,"
      6 = "06-25 TO 34,"
      7 = "07-35 TO 44,"
      8 = "08-45 TO 54,"
      9 = "09-55 TO 64,"
      10 = "10-65 AND OVER"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00030F 
      1 = "01-CORRECT"
      2 = "02-NO, INCORRECT"
   ;
   value V00031F 
      1 = "01-VERY EXPERIENCED"
      2 = "02-SOMEWHAT EXPERIENCED"
      3 = "03-SOMEWHAT INEXPERIENCED, OR"
      4 = "04-VERY INEXPERIENCED"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00039F 
      1 = "01-0 TO 5"
      2 = "02-6 TO 10"
      3 = "03-11 TO 15"
      4 = "04-16 TO 24"
      5 = "05-25 TO 34"
      6 = "06-35 TO 44"
      7 = "07-45 TO 54"
      8 = "08-55 TO 64"
      9 = "09-65 AND OVER"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00038F 
      1 = "01-MALE"
      2 = "02-FEMALE"
      99 = "99-REFUSED"
   ;
   value V00037F 
      1 = "01-16 TO 24"
      2 = "02-25 TO 34"
      3 = "03-35 TO 44"
      4 = "04-45 TO 54"
      5 = "05-55 TO 64"
      6 = "06-65 AND OVER"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00041F 
      1 = "01-A POWER BOAT,"
      2 = "02-A SAILBOAT,"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JETSKI,"
      4 = "04-A CANOE,"
      5 = "05-A KAYAK, OR"
      6 = "06-SOMETHING ELSE?"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00042F 
      1 = "01-POWER BOAT"
      2 = "02-SAILBOAT"
      3 = "03-PERSONAL WATERCRAFT SUCH AS A JETSKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE?"
   ;
   value V00048F 
      1 = "01-THE PERSON ON THE PHONE"
      2 = "02-THE \:P2SEX: AGED \:SLAGEX2:"
      3 = "03-THE \:P3SEX: AGED \:SLAGEX3:"
      4 = "04-THE \:P4SEX: AGED \:SLAGEX4:"
      5 = "05-THE \:P5SEX: AGED \:SLAGEX5:"
      6 = "06-THE \:P6SEX: AGED \:SLAGEX6:"
      7 = "07-THE \:P7SEX: AGED \:SLAGEX7:"
      8 = "08-THE \:P8SEX: AGED \:SLAGEX8:"
      9 = "09-THE \:P9SEX: AGED \:SLAGEX9:"
      10 = "10-THE \:P10SEX: AGED \:SLAGEX10:"
   ;
   value V00049F 
      1 = "01-FIRST AID KIT"
      2 = "02-EQUIPMENT FOR REACHING SOMEONE IN WATER"
      3 = "03-FIRE EXTINGUISHER"
      4 = "04-VISUAL DISTRESS SIGNALS"
      5 = "05-SOUND SIGNALS"
      6 = "06-EMERGENCY POSITION INDICATING RADIO BEACON"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00068F 
      1 = "01-WITH FRIENDS OR FAMILY"
      2 = "02-AT A BED AND BREAKFAST"
      3 = "03-AT A HOTEL OR MOTEL"
      4 = "04-AT A CAMPGROUND, OR"
      5 = "05-ON BOARD THE BOAT"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00076F 
      1 = "01-ANY ROWBOATS"
      2 = "02-ANY INFLATABLE BOATS"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00077F 
      1 = "01-ANY CABIN MOTORBOATS"
      2 = "02-ANY JET BOATS"
      3 = "03-ANY OPEN MOTORBOATS"
      4 = "04-ANY PONTOON BOATS"
      5 = "05-ANY HOUSEBOATS"
      6 = "06-ANY AIRBOATS"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00078F 
      1 = "01-ANY AUXILIARY MOTOR SAIL BOAT"
      2 = "02-ANY SAIL ONLY BOAT"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00079F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NH"
      34 = "34-NJ"
      35 = "35-NM"
      36 = "36-NY"
      37 = "37-NC"
      38 = "38-ND"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RI"
      45 = "45-SC"
      46 = "46-SD"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WV"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PR"
      88 = "88-THE BOAT WAS NOT IN THE UNITED STATES"
      96 = "96-OTHER (SPECIFY)"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00080F 
      1 = "01-LAKE"
      2 = "02-BAY"
      3 = "03-RIVER"
      4 = "04-CANAL"
      5 = "05-INTERCOASTAL WATERWAY"
      6 = "06-OCEAN"
      7 = "07-OTHER (SPECIFY)"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00081F 
      1 = "01-FRESHWATER?"
      2 = "02-SALTWATER?"
      3 = "03-BRACKISH WATER?"
      97 = "97- DON'T KNOW"
      99 = "99- REFUSED"
   ;
   value V00082F 
      1 = "01-RECORD NAME"
      99 = "99-REFUSED"
   ;
run;
